package QEMU::Manager::Device;


use strict;
use warnings;

use base qw(Net::DBus::Object);
use Net::DBus::Exporter qw(com.redhat.qemu.manager.Device);


sub new {
    my $class = shift;
    my $machine = shift;
    my $type = shift;
    my $name = shift;
    my $self = $class->SUPER::new($machine,
				  "/device/$type/$name");

    $self->{type} = $type;
    $self->{name} = $name;
    $self->{config} = shift;
    
    bless $self, $class;

    return $self;
}


sub get_config {
    my $self = shift;
    my $name = shift;
    my $default = shift;
    return $self->{config}->get($name, $default);
}


dbus_signal("config_changed", ["string", "string"]);
sub set_config {
    my $self = shift;
    my $name = shift;
    my $value = shift;
    my $caller = shift;
    $self->{config}->set($name, $value);
    $self->emit_signal("config_changed", $name, $caller);
}


dbus_method("get_device_type", [], ["string"]);
sub get_device_type {
    my $self = shift;
    return $self->{type};
}


dbus_method("get_device_name", [], ["string"]);
sub get_device_name {
    my $self = shift;
    return $self->{name};
}

sub get_command_line_args {
    my $self = shift;
    
    return ();
}

sub get_environment_variables {
    my $self = shift;
    
    return ();
}
