package QEMU::Manager::Device::Display;


use strict;
use warnings;

use base qw(QEMU::Manager::Device);

use Net::DBus::Exporter qw(com.redhat.qemu.manager.device.Display);

our %TYPES = (
	      "vga" => "-std-vga",
	      "svga" => "",
	      );

dbus_method("get_type", [], ["string"]);
sub get_type {
    my $self = shift;
    return $self->get_config("type", "svga");
}

dbus_method("set_type", ["string", "caller"]);
sub set_type {
    my $self = shift;
    my $type = shift;
    my $caller = shift;
    die "unsupported display type '$type'" 
	unless exists $TYPES{$type};
    
    $self->set_config("type", $type, $caller);
}


dbus_method("get_display", [], ["string"]);
sub get_display {
    my $self = shift;
    
    return $self->get_config("display", ":0.0");
}


dbus_method("set_display", ["string", "caller"]);
sub set_display {
    my $self = shift;
    my $name = shift;
    my $caller = shift;
    $self->set_config("display", $name, $caller);
}

sub get_command_line_args {
    my $self = shift;
    my $arg = $TYPES{$self->get_type};
    if ($arg ne "") {
	return ($arg);
    } else {
	return ();
    }
}


sub get_environment_variables {
    my $self = shift;
    
    return ( DISPLAY => $self->get_display );
}

1;
