package QEMU::Manager::Device::NIC;

use strict;
use warnings;

use base qw(QEMU::Manager::Device);

use Net::DBus::Exporter qw(com.redhat.qemu.manager.device.NIC);

our $MAC_GENERIC = "00:00:00:00:00:00";

dbus_method("get_mac_address", [], ["string"]);
sub get_mac_address {
    my $self = shift;
    return $self->get_config("mac-address", $MAC_GENERIC);
}


dbus_method("has_mac_address", [], ["boolean"]);
sub has_mac_address {
    my $self = shift;
    return $self->get_mac_address eq $MAC_GENERIC ? 0 : 1;
}


dbus_method("set_mac_address", ["string", "caller"]);
sub set_mac_address {
    my $self = shift;
    my $mac = shift;
    my $caller = shift;
    die "malformed mac address '$mac'"
	unless $mac =~ /^[a-fA-F0-9][a-fA-F0-9]?(:[a-fA-F0-9][a-fA-F0-9]?){5}$/;
    
    $self->set_config("mac-address", $mac, $caller);
}


dbus_method("get_vlan", [], ["uint32"]);
sub get_vlan {
    my $self = shift;
    return $self->get_config("vlan", 0);
}

dbus_method("set_vlan", ["uint32", "caller"]);
sub set_vlan {
    my $self = shift;
    my $vlan = shift;
    my $caller = shift;
    $self->set_config("vlan", $vlan, $caller);
}

my %SCOPES = (
	      "local" => 1,
	      "mcast" => 1,
	      "bridged" => 1,
	      );

dbus_method("get_scope", [], ["string"]);
sub get_scope {
    my $self = shift;
    return $self->get_config("scope", "local");
}

dbus_method("set_scope", ["string", "caller"]);
sub set_scope {
    my $self = shift;
    my $scope = shift;
    my $caller = shift;
    die "unknown scope '$scope'"
	unless exists $SCOPES{$scope};
    
    $self->set_config("scope", $scope, $caller);
}

sub get_command_line_args {
    my $self = shift;
    my @args;
    if ($self->has_mac_address) {
	push @args, "-net", "nic,vlan=" . $self->get_vlan . ",macaddr=" . $self->get_mac_address;
    } else {
	push @args, "-net", "nic,vlan=" . $self->get_vlan;
    }
    my $scope = $self->get_scope;
    if ($scope eq "local") {
	push @args, "-net", "user,vlan=" . $self->get_vlan;
    } elsif ($scope eq "bridged") {
	push @args, "-net", "vde,vlan=" . $self->get_vlan . ",sock=/var/run/vde" . $self->get_vlan;
    } else {
	# XXX is our auto-mcast IP addr good ? see RFC ?
	push @args, "-net", "socket,vlan=" . $self->get_vlan . ",mcast=239.192.168." . ($self->get_vlan+1) . ":9876";
    }
    return @args;
}

1;
