package QEMU::Manager::Snapshot;

use strict;
use warnings;

use base qw(Net::DBus::Object);
use Net::DBus::Exporter qw(com.redhat.qemu.manager.Snapshot);


sub new {
    my $class = shift;
    my $machine = shift;
    my $name = shift;
    my $self = $class->SUPER::new($machine,
				  "/snapshot/$name");

    $self->{name} = $name;
    $self->{config} = shift;
    
    bless $self, $class;

    return $self;
}


sub get_config {
    my $self = shift;
    my $name = shift;
    my $default = shift;
    return $self->{config}->get($name, $default);
}


dbus_signal("config_changed", ["string"]);
sub set_config {
    my $self = shift;
    my $name = shift;
    my $value = shift;
    $self->{config}->set($name, $value);
    $self->emit_signal("config_changed", $name);
}


dbus_method("get_creation_date", [], ["uint32"]);
sub get_creation_date {
    my $self = shift;
    return $self->get_config("date");
}

dbus_method("get_machine_serial", [], ["uint32"]);
sub get_machine_serial {
    my $self = shift;
    return $self->get_config("serial");
}

dbus_method("get_label", [], ["string"]);
sub get_label {
    my $self = shift;
    return $self->get_config("label", "Snapshot " . $self->get_creation_date);
}

dbus_method("set_label", ["string"]);
sub set_label {
    my $self = shift;
    my $label = shift;
    return $self->set_config("label", $label);
}

dbus_method("get_filename", [], ["string"]);
sub get_filename {
    my $self = shift;
    return $self->get_config("filename");
}

